Liberia para resolver ecuaciones

Instalar setuptools
pip install setuptools

Instalar Twine
pip install twine

Para crear una versión
python setup.py sdist bdist_wheel

Para subir una versión a PyPi
python -m twine upload dist/*
